<?php

class DatabaseBackup {
    private $config;
    private $backup_dir;

    public function __construct($config) {
        $this->config = $config;
        $this->backup_dir = __DIR__ . '/database_backups';
        if (!file_exists($this->backup_dir)) {
            mkdir($this->backup_dir, 0755, true);
        }
    }

    public function createCompressedBackup($source_db, $target_db) {
        try {
            ini_set('max_execution_time', 0);
            ini_set('memory_limit', '512M');

            $timestamp = date('Y-m-d_H-i-s');
            $backup_file = "{$this->backup_dir}/{$source_db}_{$timestamp}.sql.gz";

            // Create compressed backup
            $dump_command = sprintf(
                'mysqldump -h %s -u %s -p%s --routines --triggers --events --skip-lock-tables %s | gzip > %s',
                escapeshellarg($this->config['dbhost']),
                escapeshellarg($this->config['dbuser']),
                escapeshellarg($this->config['dbpwd']),
                escapeshellarg($source_db),
                escapeshellarg($backup_file)
            );

            exec($dump_command, $output, $return_var);
            if ($return_var !== 0) {
                throw new Exception("فشل في إنشاء النسخة الاحتياطية المضغوطة");
            }

            // Restore to target database
            $restore_command = sprintf(
                'gunzip < %s | mysql -h %s -u %s -p%s %s',
                escapeshellarg($backup_file),
                escapeshellarg($this->config['dbhost']),
                escapeshellarg($this->config['dbuser']),
                escapeshellarg($this->config['dbpwd']),
                escapeshellarg($target_db)
            );

            exec($restore_command, $output, $return_var);
            if ($return_var !== 0) {
                throw new Exception("فشل في استعادة قاعدة البيانات");
            }

            // Copy views
            $this->copyViews($source_db, $target_db);

            return [
                "status" => "success", 
                "message" => "تم النسخ بنجاح",
                "backup_file" => $backup_file
            ];

        } catch (Exception $e) {
            error_log("Error in DatabaseBackup: " . $e->getMessage());
            return ["status" => "error", "message" => $e->getMessage()];
        }
    }

    private function copyViews($source_db, $target_db) {
        $mysqli = new mysqli(
            $this->config['dbhost'],
            $this->config['dbuser'],
            $this->config['dbpwd']
        );

        try {
            $mysqli->select_db($source_db);
            $views_result = $mysqli->query("
                SELECT TABLE_NAME, VIEW_DEFINITION 
                FROM information_schema.VIEWS 
                WHERE TABLE_SCHEMA = '$source_db'
            ");

            if ($views_result) {
                $mysqli->select_db($target_db);
                while ($view = $views_result->fetch_assoc()) {
                    $view_name = $view['TABLE_NAME'];
                    $view_def = $view['VIEW_DEFINITION'];
                    $mysqli->query("CREATE OR REPLACE VIEW `$view_name` AS $view_def");
                }
            }
        } finally {
            $mysqli->close();
        }
    }
}
