<?php

require '../composer/vendor/autoload.php';

use Firebase\JWT\JWT;
use GuzzleHttp\Client;

$pushmessage = new pushmessage();

class pushmessage {

    public function sendMessage($params) {
        $rtn = $this->sendMessageAndroidAndIos($params['device_token_id'], $params);
        return $rtn;
    }

    private static function getAccessToken($credentialsPath) {
        $credentials = json_decode(file_get_contents($credentialsPath), true);
        $now_seconds = time();
        $payload = [
            'iss' => $credentials['client_email'],
            'sub' => $credentials['client_email'],
            'aud' => $credentials['token_uri'],
            'iat' => $now_seconds,
            'exp' => $now_seconds + 3600,
            'scope' => 'https://www.googleapis.com/auth/firebase.messaging',
        ];
        try {
            $jwt = JWT::encode($payload, $credentials['private_key'], 'RS256'); // استخدم JWT::encode لتوقيع التوكن
            $client = new Client();
            $response = $client->post($credentials['token_uri'], [
                'form_params' => [
                    'grant_type' => 'urn:ietf:params:oauth:grant-type:jwt-bearer',
                    'assertion' => $jwt,
                ],
            ]);

            $data = json_decode($response->getBody(), true);
        } catch (\Exception $e) {
            return false;
        }
        return $data['access_token'];
    }

    public function sendMessageAndroidAndIos($device_token_id, $params) {
        $path = '../uploads/' . DEALERUPLOAD . '/firebase/' . $params['notification_file_json'];
        $credentials = json_decode(file_get_contents($path), true);
        $projectId = $credentials['project_id'];
        $accessToken = $this->getAccessToken($path);
        if ($accessToken) {
            $url = "https://fcm.googleapis.com/v1/projects/$projectId/messages:send";
            $notification = [
                'message' => [
                    'token' => "$device_token_id", // هنا يجب أن يكون token صالحًا
                    'data' => [
                        'push' => 'true',
                        'type' => $params['data']['notification_type'], // تأكد من تسمية المفتاح بشكل صحيح
                        'id' => (string) $params['data']['notification_id'], // تحويل إلى string لضمان التوافق
                        'url' => $params['data']['url'] || '', // إضافة شرط للتأكد من عدم وجود null
                        'body' => strip_tags($params['data']['notifiy_message']),
                        'order_id' => $params['data']['order_id'],
                        'order_title' => $params['data']['order_title'],
                        'img' => $params['data']['img'],
                        'user_name' => $params['data']['user_name'],
                        'user_id' => $params['data']['user_id'],
                        'forceStart' => '1',
                    ],
                    'notification' => [
                        'title' => strip_tags($params['data']['user_name']),
                        'body' => strip_tags($params['data']['notifiy_message']),
                        'image' => $params['data']['image_url'],
                    ],
                    'android' => [
                        'notification' => [
                            'sound' => 'default', // التأكد من وجود صوت افتراضي للإشعارات
                        ],
                    ],
                    'apns' => [
                        'payload' => [
                            'aps' => [
                                'sound' => 'default', // إضافة الصوت الافتراضي لأجهزة iOS
                            ],
                        ],
                    ],
                ],
            ];

            $headers = ['Authorization: Bearer ' . $accessToken, 'Content-Type: application/json'];

            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($notification));
            $result = curl_exec($ch);
            $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE); // للحصول على رمز حالة HTTP
            curl_close($ch);
            if ($httpCode !== 200) {
                //  echo "Error --: " . $result;
            }
            return $result;
        }
    }

}
