<?php

$trademarksObj = new Trademarks();

class Trademarks {

    private $mDb;
    private $mConfig;
    private $dateTime;
    private $lang_code;

    public function __construct() {
        global $Config;

        // Initialize database connection (assuming iplus is a database handler class)
        $this->mDb = new iplus();

        // Set configurations and default values
        $this->mConfig = $Config;
        $this->dateTime = date('Y-m-d H:i:s');
        $this->lang_code = defined('LANGUAGE') ? LANGUAGE : 'en'; // Provide a default if LANGUAGE is not defined
    }

    function getTrademarks($aStart, $aLimit, $sort, $type, $searchTitle, $searchCategoryId, $id = '') {

        $sql = "SELECT  t.* ,tl.title,tl.description  FROM trademarks t";
        $sql .= " LEFT JOIN `trademark_langs` tl ON t.id = tl.trademark_id  AND  tl.lang_code = 'ar'  ";
        $sql .= " LEFT JOIN `products` p ON  p.trademark_id    =  t.id ";
        $sql .= " LEFT JOIN `product_services` ps ON ps.product_id = p.id    ";
        $sql .= " WHERE t.id > 0 and t.active = '1'   ";
        $sql .= " AND ps.service_id  in ($searchCategoryId)  ";
        $sql .= $id ? " AND t.id='{$id}' " : '';
        $sql .= $searchTitle ? ' AND (tl.title like "%' . $searchTitle . '%" ||  t.code like "%' . $searchTitle . '%" || t.`alternate_words_array` like "%' . $searchTitle . '%"  ) ' : '';
        $sql .= $sort == 'title' ? " group by t.id  ORDER BY tl.{$sort} {$type} " : "  group by t.id  ORDER BY t.{$sort} {$type} ";
        $sql .= $aLimit ? " LIMIT {$aStart}, {$aLimit}" : '';
// 	 echo $sql."<hr>";
        //  echo $sql; die();

        return $this->mDb->getAll($sql);
    }
public function getFamousTradeMarks($services) {
    try {
        // التحقق من صحة البيانات
        if (empty($services) || !is_array($services)) {
            return []; 
        }

        // استخراج معرفات الخدمات
        $service_ids = fetchArrayValue_from_dataBase($services, 'id');
        if (empty($service_ids)) {
            return []; 
        }

        // تحويل المعرفات إلى مصفوفة أعداد صحيحة
        $service_ids_array = array_map('intval', explode(',', $service_ids));

        // التحقق من أن المصفوفة ليست فارغة
        if (empty($service_ids_array)) {
            return []; 
        }

        // بناء علامات الاستفهام بناءً على عدد المعرفات
        $placeholders = implode(',', array_fill(0, count($service_ids_array), '?'));

        // بناء الاستعلام
        $sql = "SELECT t.*, tl.title, COUNT(t.id) as count_t 
                FROM trademarks t
                LEFT JOIN trademark_langs tl ON t.id = tl.trademark_id AND tl.lang_code = 'ar'
                LEFT JOIN products p ON p.trademark_id = t.id
                LEFT JOIN product_services ps ON ps.product_id = p.id
                WHERE t.id > 0 AND ps.service_id IN ($placeholders) AND t.active = '1'
                GROUP BY t.id
                ORDER BY count_t DESC";

        // تحضير الاستعلام
        $stmt = $this->mDb->connect()->prepare($sql);

        // ربط القيم مع المتغيرات
        foreach ($service_ids_array as $index => $id) {
            $stmt->bindValue($index + 1, $id, PDO::PARAM_INT); 
        }

        // تنفيذ الاستعلام وإرجاع النتائج
        $stmt->execute();
        return $stmt->fetchAll(PDO::FETCH_ASSOC);

    } catch (PDOException $e) {
        // تسجيل الخطأ
        error_log("Database Error: " . $e->getMessage());
        return [];
    }
}

//    public function getFamousTradeMarks($services) {
//        // التحقق إذا كانت المعاملات تحتوي على بيانات صالحة
//        if (empty($services) || !is_array($services)) {
//            return []; // إرجاع مصفوفة فارغة في حالة عدم وجود خدمات
//        }
//
//        // استخراج قيم 'id' من البيانات
//        $service_ids = fetchArrayValue_from_dataBase($services, 'id');
//
//        // التحقق إذا كانت المصفوفة فارغة، إذا كانت فارغة نرجع مصفوفة فارغة
//        if (empty($service_ids)) {
//            return []; // إرجاع مصفوفة فارغة إذا لم توجد معرفات للخدمات
//        }
//
//        // تحويل السلسلة المفصولة بفواصل إلى مصفوفة من القيم
//        $service_ids_array = explode(',', $service_ids);
//
//        // إنشاء علامات الاستفهام بناءً على عدد العناصر في $service_ids_array
//        $placeholders = implode(',', array_fill(0, count($service_ids_array), '?'));
//
//        // بناء الاستعلام مع المعاملات المعدة مسبقًا
//        $sql = "SELECT t.*, tl.title, COUNT(t.id) as count_t 
//            FROM trademarks t
//            LEFT JOIN trademark_langs tl ON t.id = tl.trademark_id AND tl.lang_code = 'ar'
//            LEFT JOIN products p ON p.trademark_id = t.id
//            LEFT JOIN product_services ps ON ps.product_id = p.id
//            WHERE t.id > 0 AND ps.service_id IN ($placeholders) AND t.active = '1'
//            GROUP BY t.id
//            ORDER BY count_t DESC";
//
//        // تحضير الاستعلام
//        $stmt = $this->mDb->connect()->prepare($sql);
//
//        // ربط القيم مع الاستعلام
//        foreach ($service_ids_array as $index => $id) {
//            $stmt->bindValue($index + 1, $id, PDO::PARAM_INT); // ربط القيم مع المتغيرات
//        }
//        // تنفيذ الاستعلام
//        $stmt->execute();
//        // إرجاع النتائج
//        return $stmt->fetchAll(PDO::FETCH_ASSOC);
//    }

    function getAllTrademarks($aStart, $aLimit, $searchTitle) {

        $sql = "SELECT t.id ,tl.title AS name FROM trademarks t";
        $sql .= " LEFT JOIN `trademark_langs` tl ON t.id = tl.trademark_id AND tl.lang_code ='{$this->lang_code}'";
        $sql .= " WHERE t.id > 0    ";
        $sql .= $searchTitle ? ' AND (tl.title like "%' . $searchTitle . '%" ||  t.code like "%' . $searchTitle . '%" ) ' : '';
        $sql .= " AND  t.active ='1' ";
        $sql .= " ORDER BY tl.title ASC ";
        $sql .= $aLimit ? " LIMIT {$aStart}, {$aLimit}" : '';
//		   echo $sql; die();
        $res = $this->mDb->getAll($sql);
        return $res ? $res : [];
    }
}
